@@ -12,9 +12,10 @@ file or a plain-text file.
 
 =head1 AUTHOR
 
- Anagha Kulkarni, University of Minnesota, Duluth
+ Anagha Kulkarni, Carnegie-Mellon University
 
  Ted Pedersen, University of Minnesota, Duluth
+ tpederse at d.umn.edu
 
 =head1 COPYRIGHT
 
